aboutsummaryrefslogtreecommitdiff
path: root/hardinfo
diff options
context:
space:
mode:
Diffstat (limited to 'hardinfo')
-rw-r--r--hardinfo/gpu_util.c6
1 files changed, 2 insertions, 4 deletions
diff --git a/hardinfo/gpu_util.c b/hardinfo/gpu_util.c
index ba72b907..cae15f91 100644
--- a/hardinfo/gpu_util.c
+++ b/hardinfo/gpu_util.c
@@ -154,11 +154,9 @@ static void make_nice_name(gpud *s) {
device_str = unk_d;
/* try and a get a "short name" for the vendor */
- const Vendor *v = vendor_match(vendor_str, NULL);
- if (v && v->name_short && *v->name_short != 0)
- vendor_str = v->name_short;
+ vendor_str = vendor_get_shortest_name(vendor_str);
- /* These two former special cases are currently handled by the vendor_match()
+ /* These two former special cases are currently handled by the vendor_get_shortest_name()
* function well enough, but the notes are preserved here. */
/* nvidia PCI strings are pretty nice already,
* just shorten the company name */